#
# spec file for package lua51
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define major_version 5.1
%define libname liblua5_1-5
Name:           lua51
Version:        5.1.5
Release:        15.38
Summary:        Small Embeddable Language with Procedural Syntax
License:        MIT
Group:          Development/Languages/Other
Url:            http://www.lua.org
Source:         http://www.lua.org/ftp/lua-%{version}.tar.gz
Source99:       baselibs.conf
# PATCH-FIX-SUSE tweak the buildsystem to produce what is needed for SUSE
Patch0:         lua-build-system.patch
BuildRequires:  libtool
BuildRequires:  lua-macros
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       lua = %{version}
Provides:       Lua(API) = %{major_version}

%description
Lua is a programming language originally designed for extending
applications, but is also frequently used as a general-purpose,
stand-alone language.

Lua combines procedural syntax (similar to Pascal) with
data description constructs based on associative arrays and extensible
semantics. Lua is dynamically typed, interpreted from byte codes, and
has automatic memory management, making it suitable for configuration,
scripting, and rapid prototyping. Lua is implemented as a small library
of C functions, written in ANSI C.

%package devel
Summary:        Development files for lua
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}
Requires:       lua-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       lua-devel = %{version}
Provides:       Lua(devel) = %{major_version}
Provides:       pkgconfig(lua) = %{version}

%description devel
Lua is a programming language originally designed for extending
applications, but is also frequently used as a general-purpose,
stand-alone language.

This package contains files needed for embedding lua into your
application.

%package -n %{libname}
Summary:        The Lua integration library
Group:          System/Libraries
Provides:       %{name}-libs = %{version}
Obsoletes:      %{name}-libs < %{version}
Provides:       liblua5_1 = %{version}-%{release}
Obsoletes:      liblua5_1 < %{version}-%{release}

%description -n %{libname}
Lua is a programming language originally designed for extending
applications, but is also frequently used as a general-purpose,
stand-alone language.

Lua combines procedural syntax (similar to Pascal) with
data description constructs based on associative arrays and extensible
semantics. Lua is dynamically typed, interpreted from byte codes, and
has automatic memory management, making it suitable for configuration,
scripting, and rapid prototyping. Lua is implemented as a small library
of C functions, written in ANSI C.

%package doc
Summary:        Documentation for Lua, a small embeddable language
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
Lua is a programming language originally designed for extending
applications, but is also frequently used as a general-purpose,
stand-alone language.

Lua combines procedural syntax (similar to Pascal) with
data description constructs based on associative arrays and extensible
semantics. Lua is dynamically typed, interpreted from byte codes, and
has automatic memory management, making it suitable for configuration,
scripting, and rapid prototyping. Lua is implemented as a small library
of C functions, written in ANSI C.

%prep
%setup -q -n lua-%{version}
%autopatch -p1

# manpage
cat doc/lua.1  | sed 's/TH LUA 1/TH LUA%{major_version} 1/' > doc/lua%{major_version}.1
cat doc/luac.1 | sed 's/TH LUAC 1/TH LUAC%{major_version} 1/' > doc/luac%{major_version}.1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
sed -i -e "s@lib/lua/@%{_lib}/lua/@g" src/luaconf.h
export LIBTOOL="libtool --quiet"
make %{?_smp_mflags} -C src \
    CC="cc" \
    MYCFLAGS="%{optflags} -std=gnu99 -D_GNU_SOURCE -fPIC -DLUA_USE_LINUX -DLUA_COMPAT_MODULE" \
    MYLIBS="-Wl,-E -ldl -lreadline -lhistory -lncurses" \
    V=%{major_version} \
    all

%install
make install \
    V=%{major_version} \
    INSTALL_TOP="%{buildroot}%{_prefix}" \
    INSTALL_LIB="%{buildroot}%{_libdir}"

find %{buildroot} -type f -name "*.la" -delete -print

# create pkg-config file
cat > lua%{major_version}.pc <<-EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_prefix}/include/lua%{major_version}
INSTALL_LMOD=%{_datadir}/lua/%{major_version}
INSTALL_CMOD=%{_libdir}/lua/%{major_version}

Name: Lua %{major_version}
Description: An Extensible Extension Language
Version: %{version}
Libs: -llua%{major_version} -lm
Cflags: -I\${includedir}
EOF
install -D -m 644 lua%{major_version}.pc %{buildroot}/%{_libdir}/pkgconfig/lua%{major_version}.pc

# update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for file in lua luac ; do
    touch "%{buildroot}%{_sysconfdir}/alternatives/${file}"
    ln -sf "%{_sysconfdir}/alternatives/${file}" "%{buildroot}%{_bindir}/${file}"
    touch "%{buildroot}%{_sysconfdir}/alternatives/${file}.1%{ext_man}"
    ln -sf "%{_sysconfdir}/alternatives/${file}.1%{ext_man}" "%{buildroot}%{_mandir}/man1/${file}.1%{ext_man}"
done

# Compat link with older unprefixed library and with soname 0 from deb/etc
ln -s %{_libdir}/liblua%{major_version}.so.%{major_version}.0 %{buildroot}%{_libdir}/liblua%{major_version}.so.%{major_version}
ln -s %{_libdir}/liblua%{major_version}.so.%{major_version}.0 %{buildroot}%{_libdir}/liblua%{major_version}.so.0
ln -s %{_libdir}/liblua%{major_version}.so.%{major_version}.0 %{buildroot}%{_libdir}/liblua.so.%{major_version}
# Library devel alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/liblua.so
ln -sf %{_sysconfdir}/alternatives/liblua.so %{buildroot}%{_libdir}/liblua.so
touch %{buildroot}%{_sysconfdir}/alternatives/lua.pc
ln -sf %{_sysconfdir}/alternatives/lua.pc %{buildroot}%{_libdir}/pkgconfig/lua.pc

%check
cd src
LD_LIBRARY_PATH=`pwd` ./lua%{major_version} -e 'print(0)' > /dev/null

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%post
%{_sbindir}/update-alternatives --install                                                 \
            %{_bindir}/lua            lua       %{_bindir}/lua%{major_version}         51 \
    --slave %{_bindir}/luac           luac      %{_bindir}/luac%{major_version}           \
    --slave %{_mandir}/man1/lua.1%{ext_man}  lua.1%{ext_man}  %{_mandir}/man1/lua%{major_version}.1%{ext_man}  \
    --slave %{_mandir}/man1/luac.1%{ext_man} luac.1%{ext_man} %{_mandir}/man1/luac%{major_version}.1%{ext_man}

%postun
if [ "$1" = 0 ] ; then
    %{_sbindir}/update-alternatives --remove lua %{_bindir}/lua%{major_version}
fi

%post devel
%{_sbindir}/update-alternatives --install                                                     \
            %{_libdir}/liblua.so        liblua.so %{_libdir}/liblua%{major_version}.so     51 \
    --slave %{_libdir}/pkgconfig/lua.pc lua.pc    %{_libdir}/pkgconfig/lua%{major_version}.pc

%postun devel
if [ "$1" = 0 ] ; then
    %{_sbindir}/update-alternatives --remove liblua.so %{_libdir}/liblua%{major_version}.so
fi

%files
%doc README
%dir %{_libdir}/lua
%dir %{_libdir}/lua/%{major_version}
%dir %{_datadir}/lua
%dir %{_datadir}/lua/%{major_version}
%{_bindir}/lua%{major_version}
%{_bindir}/luac%{major_version}
%{_mandir}/man1/lua%{major_version}.1%{ext_man}
%{_mandir}/man1/luac%{major_version}.1%{ext_man}
# alternatives
%{_bindir}/lua
%{_bindir}/luac
%{_mandir}/man1/lua.1%{ext_man}
%{_mandir}/man1/luac.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/lua
%ghost %{_sysconfdir}/alternatives/luac
%ghost %{_sysconfdir}/alternatives/lua.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/luac.1%{ext_man}

%files -n %{libname}
%{_libdir}/liblua%{major_version}.so.*
%{_libdir}/liblua.so.*

%files devel
%dir %{_includedir}/lua%{major_version}
%{_includedir}/lua%{major_version}/lauxlib.h
%{_includedir}/lua%{major_version}/lua.h
%{_includedir}/lua%{major_version}/lua.hpp
%{_includedir}/lua%{major_version}/luaconf.h
%{_includedir}/lua%{major_version}/lualib.h
%{_libdir}/liblua%{major_version}.a
%{_libdir}/liblua%{major_version}.so
%{_libdir}/pkgconfig/lua%{major_version}.pc
# alternatives
%{_libdir}/liblua.so
%{_libdir}/pkgconfig/lua.pc
%ghost %{_sysconfdir}/alternatives/liblua.so
%ghost %{_sysconfdir}/alternatives/lua.pc

%files doc
%doc doc/*

%changelog
* Fri Aug  2 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static library.
* Tue Jul 25 2017 tchvatal@suse.com
- Provide symbol for pkgconfig
* Mon Jul 24 2017 dimstar@opensuse.org
- Add INSTALL_LMOD and INSTALL_CMOD variables to lua51.pc: this is
  queried for example by rrdtool's buildsystem.
* Thu Jul 20 2017 tchvatal@suse.com
- Properly set includedir in the .pc file
* Mon Jul 10 2017 tchvatal@suse.com
- Remove lua macros to favor split package
- Sync with lua53 package to have exactly same approach of deployment
- Add patch fixing the build using libtool:
  * lua-build-system.patch
- Remove patches that are obsolete by above:
  * lua51-5.1.5-libdir.diff
  * lua51-5.1.5-module-path.diff
  * lua51-5.1.5-pkgconfig.patch
  * lua51-5.1.5-shared.diff
* Sat Sep  5 2015 i@marguerite.su
- provides Lua(API) and Lua(devel)
- adjust update-alternative weight
- macros installs to -devel
* Fri Jul 31 2015 jengelh@inai.de
- Update RPM group classification
* Fri Sep 12 2014 pgajdos@suse.com
- fix update-alternatives
* Wed Sep 10 2014 pgajdos@suse.com
- fix /etc/rpm/macros.lua51 perms
* Thu May  1 2014 mailaender@opensuse.org
- Added a softlink to retain compatibility with .so naming from
  the DEB world which is the quasi standard in gaming nowadays.
* Mon Apr 14 2014 pgajdos@suse.com
- revert last change: breaks builds of dependent packages.
  They include lua51-devel and expects rpm macros to be available.
  rpm macros use the interpreter.
* Tue Mar 18 2014 Rene.vanPaassen@gmail.com
- correct dependency of lua51-devel, to be on the lib package, not
  on the interpreter binary
* Tue Oct 22 2013 peter.trommler@ohm-hochschule.de
- fix patch lua51-5.1.5-pkgconfig.patch
  * libdl is required not librt
* Mon Oct 21 2013 peter.trommler@ohm-hochschule.de
- refresh patch lua51-5.1.5-module-path.diff
- new patch lua51-5.1.5-pkgconfig.patch
  * fix libraries in pkgconfig file
* Thu May 16 2013 pgajdos@suse.com
- move rpm macros back, but install it in /etc/rpm/macros.lua51
  and call lua5.1 in %%lua_version definition
* Sun May  5 2013 mrdocs@opensuse.org
- move the lua rpm macros to the devel package to avoid conflict
  with lua 5.2
* Tue Apr 16 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Jun 18 2012 pgajdos@suse.com
- updated to 5.1.5:
  * bug-fix release, see http://www.lua.org/bugs.html for
    more details
  - > removed upstream-bugfix.patch
* Sat Mar 31 2012 joop.boonen@opensuse.org
- Correction in Provides and Obsolete for lua-libs
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Dec 21 2011 pgajdos@suse.com
- lua51 branched from lua package
* Tue Oct  4 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Mon Jun 14 2010 pgajdos@suse.cz
- removed -L/usr/lib from Libs: in etc/lua.pc [bnc#613497]
- used upstream bugfix patch from http://www.lua.org/download.html
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Tue Mar 23 2010 pgajdos@suse.cz
- modified LUA_PATH_DEFAULT [bnc#589441]: search modules under
  /usr/%%{_lib}/lua/%%{major_version} too
* Sat Dec 12 2009 jengelh@medozas.de
- add baselibs.conf as a source
- package documentation as noarch
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Sep 16 2009 dmueller@suse.de
- add baselibs.conf
* Mon Jun  8 2009 pgajdos@suse.cz
- package owns /usr/{lib,share}/lua directories from now
- emoved unneeded root.patch
* Thu Sep 11 2008 pgajdos@suse.cz
- updated to 5.1.4: bugfix release
* Wed Jun 11 2008 jfunk@funktronics.ca
- Set LUA_ROOT to /usr and fix INSTALL_CMOD for lib64
- Add RPM macros file
- Allows for lua-<modulename> packages like python, perl, and ruby
* Fri Mar 28 2008 coolo@suse.de
- hint the solver about the package rename
* Wed Mar 26 2008 coolo@suse.de
- do not package/provide the shared lib twice / follow shared lib
  policy
* Tue Feb 19 2008 pgajdos@suse.cz
- created -doc package
- updated to version 5.1.3, bug fix release. Fixed bugs:
  * wrong error message in some concatenations
  * too many variables in an assignment may cause a C stack
    overflow
  * an error in a module loaded through the '-l' option shows no
    traceback
  * gsub may go wild when wrongly called without its third
    argument and with a large subject
  * table.remove removes last element of a table when given
    an out-of-bound index
  * lua_setfenv may crash if called over an invalid object
  * stand-alone interpreter shows incorrect error message when
    the "message" is a coroutine.
  * debug.sethook/gethook may overflow the thread's stack
* Tue Jul 24 2007 pgajdos@suse.cz
- using /sbin/ldconfig in specfile
- updated to version 5.1.2, fixes some bugs:
  * count hook may be called without being set
  * code generated for "-nil", "-true", and "-false" is wrong
  * recursive coroutines may overflow C stack
  * wrong error message in some concatenations
  * very small numbers all collide in the hash function
* Mon Nov 27 2006 mrueckert@suse.de
- package liblua.so as symlink.
* Thu Nov 16 2006 mrueckert@suse.de
- the core package now uses update alternatives to allow installation
  of 5.0.x and 5.1.x
- devel packages will conflict now
* Tue Nov 14 2006 mrueckert@suse.de
- ARGH dont copy and paste!:
  lua-libs should not depend on lua. another run on (#217875)
* Tue Nov 14 2006 mrueckert@suse.de
- really fix the file pattern (#217875)
* Thu Nov  9 2006 mrueckert@suse.de
- splitted out lua-libs so we can install at least both libs
  in parallel. (#217875)
* Thu Oct 19 2006 dmueller@suse.de
- fix wrong prefix in lua.pc
- link liblua with -lm to satisfy unresolved symbols
* Thu Oct 19 2006 mjancar@suse.cz
- include lua.pc
* Wed Oct 18 2006 mjancar@suse.cz
- update to 5.1.1
  Language:
  * new module system.
  * new semantics for control variables of fors.
  * new semantics for setn/getn.
  * new syntax/semantics for varargs.
  * new long strings and comments.
  * new `mod' operator (`%%')
  * new length operator #t
  * metatables for all types
  API:
  * new functions: lua_createtable, lua_get(set)field, lua_push(to)integer.
  * user supplies memory allocator (lua_open becomes lua_newstate).
  * luaopen_* functionst must be called through Lua.
  Implementation:
  * new configuration scheme via luaconf.h.
  * incremental garbage collection.
  * better handling of end-of-line in the lexer.
  * fully reentrant parser (new Lua function `load')
  * better support for 64-bit machines.
  * native loadlib support for Mac OS X.
  * standard distribution in only one library (lualib.a merged into lua.a)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
- Fix shared library linking.
* Thu Sep  8 2005 anicka@suse.cz
- enable dynamic loading capability (#106845)
* Fri Apr 23 2004 mcihar@suse.cz
- initial packaging
